==> entodicton-5.51.123.tgz: package/src/generators_test.js <==
const { Generators, Generator, gs } = require('./generators.js');

const expectedConfig = {
  value: 'this is the config'
};

describe('Generator Tests', () => {
  const matcher = ({context}) => context.marker == 'earn';
  const handler = ({g, context}) => `${context.who} earns ${context.amount} ${context.units}`
  const generator = new Generator(matcher, handler);
  let context;

  beforeEach( () => {
    context = {
      "amount": 10,
      "marker": "earn",
      "units": "dollars",
      "who": "joe"
    }
  });

  it('generator match', () => {
    expect(generator.matches({}, context)).toBeTruthy()
  });

  it('generator no match', () => {
    context.marker = 'earn23';
    expect(generator.matches({}, context)).not.toBeTruthy()
  });

  it('generator apply no g', () => {
    expect(generator.apply({}, null, context, expectedConfig)).toBe('joe earns 10 dollars')
  });

  it('generator apply with g', () => {
    const g = (context) => `G(${context})`
    const handler = ({g, context}) => `${g(context.who)} earns ${g(context.amount)} ${g(context.units)}`
    const generator = new Generator(matcher, handler);
    expect(generator.apply({}, g, context, expectedConfig)).toBe('G(joe) earns G(10) G(dollars)')
  });
})

describe('Generators Tests', () => {
  const contexts = [
    {
      'marker': 'earns',
      'who': 'joe',
      'earns': 10,
      'units': 'dollars',
    },
    {
      'marker': 'earns',
      'isQuery': true,
      'who': 'joe',
      'for': 'earnings'
    }
  ]

  const generators = [
    new Generator( 
      ({context}) => { 
       const value = context.marker == 'earns' && context.isQuery;
       return value
      },
      ({g, context}) => { 
        return `What does ${g(context.who)} earn?` 
      }
    ),
    new Generator( 
      ({context}) => { return context.marker == 'earns' },
      ({g, context}) => { 
        return `${context.who} earns ${g(context.earns)} ${g(context.units)}`; 
      }
    ),
  ]

  it('apply zero', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts[0], expectedConfig);
    expect(r).toStrictEqual(['joe earns 10 dollars'])
  });

  it('apply one', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts[1], expectedConfig);
    expect(r).toStrictEqual(['What does joe earn?'])
  });

  it('apply zero one', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts, expectedConfig);
    expect(r).toStrictEqual(['joe earns 10 dollars', 'What does joe earn?'])
  });

  it('nested hash', () => {
    context = {
      'marker': 'move',
      'what': {
        'marker': 'tankConcept',
        'id': 1
      }
    }
    const generators = [
      new Generator( 
        ({context}) => context.marker == 'move',
        ({g, context, config}) => { 
          expect(config).toStrictEqual(expectedConfig)
          return `move ${g(context.what)}`
        }
      ),
      new Generator( 
        ({context}) => context.marker == 'tankConcept',
        ({g, context}) => `tank${g(context.id)}`
      ),
    ]
    const s = new Generators(generators);
    const r = s.apply({}, context, expectedConfig);
    expect(r).toStrictEqual(['move tank1'])
  });

  it('nested list', () => {
    context = {
      "language": "english",
      "number": "many",
      "marker": "toBe",
      "word": "are",
      "subject": [
        {
          "language": "english",
          "isQuery": true,
          "marker": "personConcept",
          "word": "who"
        }
      ],
      "object": [
        [
          {
            "id": "player1",
            "name": "aragon",
            "eyes": "blue",
            "weight": 82,
            "units": "kg"
          }
        ]
      ]
    }

    const generators = [
      new Generator(({context}) => context.marker == 'toBe', ({g, gs, context}) => {
        return `${gs(context.object, ' ', ' and ')}` 
      }),
      new Generator(({context}) => context.marker == 'personConcept' && context.isQuery, ({g, context}) => `who` ),
      new Generator(({context}) => context.marker == 'playerConcept', ({g, context}) => `the players` ),
      new Generator(({context}) => context.id == 'player1', ({g, context}) => `${context.name} of eyes ${context.eyes}` ),
    ]
    const s = new Generators(generators);
    const r = s.apply({}, context, expectedConfig);
    expect(r).toStrictEqual(['aragon of eyes blue'])
  });
})

==> entodicton-5.51.126.tgz: package/src/generators_test.js <==
const { Generators, Generator, gs } = require('./generators.js');

const expectedConfig = {
  value: 'this is the config'
};

const expectedResponse = {
  value: 'this is the response'
};

describe('Generator Tests', () => {
  const matcher = ({context}) => context.marker == 'earn';
  const handler = ({g, context}) => `${context.who} earns ${context.amount} ${context.units}`
  const generator = new Generator(matcher, handler);
  let context;

  beforeEach( () => {
    context = {
      "amount": 10,
      "marker": "earn",
      "units": "dollars",
      "who": "joe"
    }
  });

  it('generator match', () => {
    expect(generator.matches({}, context)).toBeTruthy()
  });

  it('generator no match', () => {
    context.marker = 'earn23';
    expect(generator.matches({}, context)).not.toBeTruthy()
  });

  it('generator apply no g', () => {
    expect(generator.apply({}, null, context, expectedConfig, expectedResponse)).toBe('joe earns 10 dollars')
  });

  it('generator apply with g', () => {
    const g = (context) => `G(${context})`
    const handler = ({g, context}) => `${g(context.who)} earns ${g(context.amount)} ${g(context.units)}`
    const generator = new Generator(matcher, handler);
    expect(generator.apply({}, g, context, expectedConfig, expectedResponse)).toBe('G(joe) earns G(10) G(dollars)')
  });
})

describe('Generators Tests', () => {
  const contexts = [
    {
      'marker': 'earns',
      'who': 'joe',
      'earns': 10,
      'units': 'dollars',
    },
    {
      'marker': 'earns',
      'isQuery': true,
      'who': 'joe',
      'for': 'earnings'
    }
  ]

  const generators = [
    new Generator( 
      ({context}) => { 
       const value = context.marker == 'earns' && context.isQuery;
       return value
      },
      ({g, context}) => { 
        return `What does ${g(context.who)} earn?` 
      }
    ),
    new Generator( 
      ({context}) => { return context.marker == 'earns' },
      ({g, context}) => { 
        return `${context.who} earns ${g(context.earns)} ${g(context.units)}`; 
      }
    ),
  ]

  it('apply zero', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts[0], expectedConfig, expectedResponse);
    expect(r).toStrictEqual(['joe earns 10 dollars'])
  });

  it('apply one', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts[1], expectedConfig, expectedResponse);
    expect(r).toStrictEqual(['What does joe earn?'])
  });

  it('apply zero one', () => {
    const s = new Generators(generators);
    const r = s.apply({}, contexts, expectedConfig, expectedResponse);
    expect(r).toStrictEqual(['joe earns 10 dollars', 'What does joe earn?'])
  });

  it('nested hash', () => {
    context = {
      'marker': 'move',
      'what': {
        'marker': 'tankConcept',
        'id': 1
      }
    }
    const generators = [
      new Generator( 
        ({context}) => context.marker == 'move',
        ({g, context, config, response}) => { 
          expect(config).toStrictEqual(expectedConfig)
          expect(response).toStrictEqual(expectedResponse)
          return `move ${g(context.what)}`
        }
      ),
      new Generator( 
        ({context}) => context.marker == 'tankConcept',
        ({g, context}) => `tank${g(context.id)}`
      ),
    ]
    const s = new Generators(generators);
    const r = s.apply({}, context, expectedConfig, expectedResponse);
    expect(r).toStrictEqual(['move tank1'])
  });

  it('nested list', () => {
    context = {
      "language": "english",
      "number": "many",
      "marker": "toBe",
      "word": "are",
      "subject": [
        {
          "language": "english",
          "isQuery": true,
          "marker": "personConcept",
          "word": "who"
        }
      ],
      "object": [
        [
          {
            "id": "player1",
            "name": "aragon",
            "eyes": "blue",
            "weight": 82,
            "units": "kg"
          }
        ]
      ]
    }

    const generators = [
      new Generator(({context}) => context.marker == 'toBe', ({g, gs, context}) => {
        return `${gs(context.object, ' ', ' and ')}` 
      }),
      new Generator(({context}) => context.marker == 'personConcept' && context.isQuery, ({g, context}) => `who` ),
      new Generator(({context}) => context.marker == 'playerConcept', ({g, context}) => `the players` ),
      new Generator(({context}) => context.id == 'player1', ({g, context}) => `${context.name} of eyes ${context.eyes}` ),
    ]
    const s = new Generators(generators);
    const r = s.apply({}, context, expectedConfig, expectedResponse);
    expect(r).toStrictEqual(['aragon of eyes blue'])
  });
})
